==> zio-aws-chimesdkmessaging_2.13-5.17.103.1-sources.jar: zio/aws/chimesdkmessaging/model/ListChannelsAssociatedWithChannelFlowResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmessaging.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListChannelsAssociatedWithChannelFlowResponse(
    channels: Option[
      Iterable[zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse = {
    import ListChannelsAssociatedWithChannelFlowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
      .builder()
      .optionallyWith(
        channels.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.channels)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
      .wrap(buildAwsValue())
}
object ListChannelsAssociatedWithChannelFlowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse =
      zio.aws.chimesdkmessaging.model
        .ListChannelsAssociatedWithChannelFlowResponse(
          channels.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          nextToken.map(value => value)
        )
    def channels: Option[List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]]
    def nextToken: Option[NextToken]
    def getChannels: ZIO[Any, AwsError, List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("channels", channels)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ) extends zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly {
    override val channels: Option[List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]] = scala
      .Option(impl.channels())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary
            .wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ): zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.17.195.3-sources.jar: zio/aws/chimesdkmessaging/model/ListChannelsAssociatedWithChannelFlowResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmessaging.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListChannelsAssociatedWithChannelFlowResponse(
    channels: Optional[
      Iterable[zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse = {
    import ListChannelsAssociatedWithChannelFlowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
      .builder()
      .optionallyWith(
        channels.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.channels)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
      .wrap(buildAwsValue())
}
object ListChannelsAssociatedWithChannelFlowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse =
      zio.aws.chimesdkmessaging.model
        .ListChannelsAssociatedWithChannelFlowResponse(
          channels.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          nextToken.map(value => value)
        )
    def channels: Optional[List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]]
    def nextToken: Optional[NextToken]
    def getChannels: ZIO[Any, AwsError, List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("channels", channels)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ) extends zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly {
    override val channels: Optional[List[
      zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.channels())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmessaging.model.ChannelAssociatedWithFlowSummary
            .wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse
  ): zio.aws.chimesdkmessaging.model.ListChannelsAssociatedWithChannelFlowResponse.ReadOnly =
    new Wrapper(impl)
}
